@@ -1,7 +1,7 @@
 /*-
  * See the file LICENSE for redistribution information.
  *
- * Copyright (c) 2009, 2011 Oracle and/or its affiliates.  All rights reserved.
+ * Copyright (c) 2009, 2013 Oracle and/or its affiliates.  All rights reserved.
  *
  */
 using System;
@@ -18,6 +18,30 @@ namespace BerkeleyDB {
             st = stats;
         }
 
+        /// <summary>
+        /// Current number of lockers allocated. 
+        /// </summary>
+        public uint AllocatedLockers { get { return st.st_lockers; } }
+        /// <summary>
+        /// Current number of locks allocated. 
+        /// </summary>
+        public uint AllocatedLocks { get { return st.st_locks; } }
+        /// <summary>
+        /// Current number of lock objects allocated.
+        /// </summary>
+        public uint AllocatedObjects { get { return st.st_objects; } }
+        /// <summary>
+        /// Initial number of locks allocated.
+        /// </summary>
+        public uint InitLocks { get { return st.st_initlocks; } }
+        /// <summary>
+        /// Initial number of lockers allocated.
+        /// </summary>
+        public uint InitLockers { get { return st.st_initlockers; } }
+        /// <summary>
+        /// Initial number of lock objects allocated.
+        /// </summary>
+        public uint InitObjects { get { return st.st_initobjects; } }
         /// <summary>
         /// Last allocated locker ID. 
         /// </summary>
@@ -79,6 +103,14 @@ namespace BerkeleyDB {
         /// </summary>
         public uint Lockers { get { return st.st_nlockers; } }
         /// <summary>
+        /// Number of hits in the thread locker cache. 
+        /// </summary>
+        public ulong LockersHit { get { return st.st_nlockers_hit; } }
+        /// <summary>
+        /// Total number of lockers reused. 
+        /// </summary>
+        public ulong LockersReused { get { return st.st_nlockers_reused; } }
+        /// <summary>
         /// Current number of locks. 
         /// </summary>
         public uint Locks { get { return st.st_nlocks; } }
@@ -179,6 +211,10 @@ namespace BerkeleyDB {
         /// </summary>
         public ulong RegionWait { get { return st.st_region_wait; } }
         /// <summary>
+        /// Size of object hash table. 
+        /// </summary>
+        public uint TableSize { get { return st.st_tablesize; } }
+        /// <summary>
         /// Transaction timeout. 
         /// </summary>
         public uint TxnTimeoutLength { get { return st.st_txntimeout; } }
@@ -188,4 +224,5 @@ namespace BerkeleyDB {
         public ulong TxnTimeouts { get { return st.st_ntxntimeouts; } }
         
     }
-}
\ No newline at end of file
+}
+
